Welcome!
========

This library contains the scripts and configuration files to install
Big Switch Network OpenStack modules and IVS to enable a Big Switch
Networks fabric as Openstack Neutron backend.


External Resources:
===================

Big Switch Networks Website: http://www.bigswitch.com
